@@ -35,7 +35,7 @@
 #![doc(
     html_logo_url = "https://raw.githubusercontent.com/RustCrypto/media/8f1a9894/logo.svg",
     html_favicon_url = "https://raw.githubusercontent.com/RustCrypto/media/8f1a9894/logo.svg",
-    html_root_url = "https://docs.rs/elliptic-curve/0.11.2"
+    html_root_url = "https://docs.rs/elliptic-curve/0.11.3"
 )]
 
 #[cfg(feature = "alloc")]
@@ -98,7 +98,7 @@ pub use {
             AffineArithmetic, PrimeCurveArithmetic, ProjectiveArithmetic, ScalarArithmetic,
         },
         public_key::PublicKey,
-        scalar::{non_zero::NonZeroScalar, Scalar},
+        scalar::{nonzero::NonZeroScalar, Scalar},
     },
     ff::{self, Field, PrimeField},
     group::{self, Group},
